import yt
import os.path

yt.enable_parallelism()

c = [0.5, 0.5, 0.5]
left=[0,0,0.5]
right=[1,1,0.5+0.03125]

ts = yt.DatasetSeries("DD0*/*.hierarchy", parallel = 4)

for ds in ts.piter():

    my_region = ds.region(center=c,left_edge=left,right_edge=right)

    # projection of baryon overdensity through narrow slab
    fn1 = str(ds) + "/" + str(ds) + "_region_nogrids_Projection_z_baryon_overdensity_baryon_overdensity.png"
    if os.path.isfile(fn1) is False:
        plot1 = yt.ProjectionPlot(ds,'z',"baryon_overdensity",weight_field="baryon_overdensity",
                                  center=c,data_source=my_region, field_parameters = {'omega_baryon': 0.046})
        plot1.set_zlim(field='baryon_overdensity',zmin=0.1,zmax=1.0e+3)
        plot1.plots['baryon_overdensity'].axes.get_xaxis().set_visible(False)
        plot1.plots['baryon_overdensity'].axes.get_yaxis().set_visible(False)
        plot1.annotate_text([0.05,-0.06],'z = %.3f' % ds.current_redshift, text_args={'size':24})
        plot1.annotate_text([0.7,-0.06],'t = %.3f Gyr' % ds.current_time.in_units('Gyr'), text_args={'size':24})
        plot1.set_cmap('baryon_overdensity','Blues')
        plot1.save("%s/%s_region_nogrids" % (ds,ds))
        plot1.set_cmap('baryon_overdensity','algae')
        plot1.annotate_grids(min_level=1,max_level=2,linewidth=1,cmap=None,edgecolors='white', alpha=1.0)
        plot1.save("%s/%s_region_withgrids" % (ds,ds))

    # projection of baryon overdensity through full volume
    fn3 = str(ds) + "/" + str(ds) + "_Projection_z_baryon_overdensity_baryon_overdensity.png"
    if os.path.isfile(fn3) is False:
        plot1a = yt.ProjectionPlot(ds,'z',"baryon_overdensity",weight_field="baryon_overdensity",
                                   center=c, field_parameters = {'omega_baryon': 0.046})
        plot1a.set_zlim(field='baryon_overdensity',zmin=0.1,zmax=1.0e+3)
        plot1a.plots['baryon_overdensity'].axes.get_xaxis().set_visible(False)
        plot1a.plots['baryon_overdensity'].axes.get_yaxis().set_visible(False)
        plot1a.annotate_text([0.05,-0.06],'z = %.3f' % ds.current_redshift, text_args={'size':24})
        plot1a.annotate_text([0.7,-0.06],'t = %.3f Gyr' % ds.current_time.in_units('Gyr'), text_args={'size':24})
        plot1a.set_cmap('baryon_overdensity','Blues')
        plot1a.save("%s/" % ds)

    # projection of baryon overdensity through narrow slab - greyscale + rainbow grids
    fn2 = str(ds) + "/" + str(ds) + "_region_withgrids_BW_Projection_z_baryon_overdensity_baryon_overdensity.png"
    if os.path.isfile(fn2) is False:
        plot1b = yt.ProjectionPlot(ds,'z',"baryon_overdensity",weight_field="baryon_overdensity",
                                   center=c,data_source=my_region, field_parameters = {'omega_baryon': 0.046})
        plot1b.set_zlim(field='baryon_overdensity',zmin=0.1,zmax=1.0e+3)
        plot1b.set_cmap('baryon_overdensity','Greys')
        plot1b.annotate_grids(min_level=1,max_level=3,linewidth=2,cmap='RAINBOW',alpha=1)
        plot1b.plots['baryon_overdensity'].axes.get_xaxis().set_visible(False)
        plot1b.plots['baryon_overdensity'].axes.get_yaxis().set_visible(False)
        plot1b.annotate_text([0.05,-0.06],'z = %.3f' % ds.current_redshift, text_args={'size':24})
        plot1b.annotate_text([0.7,-0.06],'t = %.3f Gyr' % ds.current_time.in_units('Gyr'), text_args={'size':24})
        plot1b.save("%s/%s_region_withgrids_BW" % (ds,ds))
 
    # projection of grid level (max along LOS) through narrow slab
    fn4 = str(ds) + "/" + str(ds) + "_region_Projection_z_grid_level.png"
    if os.path.isfile(fn4) is False:
        plot2 = yt.ProjectionPlot(ds,'z',"grid_level",weight_field=None,center=c,data_source=my_region, proj_style="mip")
        plot2.set_log("grid_level",False)
        plot2.set_zlim("grid_level",0,3)
        plot2.set_cmap("grid_level","hot_r")
        plot2.plots['grid_level'].axes.get_xaxis().set_visible(False)
        plot2.plots['grid_level'].axes.get_yaxis().set_visible(False)
        plot2.annotate_text([0.05,-0.06],'z = %.3f' % ds.current_redshift, text_args={'size':24})
        plot2.annotate_text([0.7,-0.06],'t = %.3f Gyr' % ds.current_time.in_units('Gyr'), text_args={'size':24})
        cb = plot2.plots['grid_level'].cb
        cb.set_label("Grid Level")
        cb.set_ticks([0,1,2,3])
        cb.set_ticklabels([0,1,2,3])
        plot2.save("%s/%s_region" % (ds,ds))

    # projection of grid level (max along LOS) through full volume
    fn5 = str(ds) + "/" + str(ds) + "_Projection_z_grid_level.png"
    if os.path.isfile(fn5) is False:
        plot2a = yt.ProjectionPlot(ds,'z',"grid_level",weight_field=None,center=c,proj_style="mip")
        plot2a.set_log("grid_level",False)
        plot2a.set_zlim("grid_level",0,3)
        plot2a.set_cmap("grid_level","hot_r")
        plot2a.plots['grid_level'].axes.get_xaxis().set_visible(False)
        plot2a.plots['grid_level'].axes.get_yaxis().set_visible(False)
        plot2a.annotate_text([0.05,-0.06],'z = %.3f' % ds.current_redshift, text_args={'size':24})
        plot2a.annotate_text([0.7,-0.06],'t = %.3f Gyr' % ds.current_time.in_units('Gyr'), text_args={'size':24})
        cb2a = plot2a.plots['grid_level'].cb
        cb2a.set_label("Grid Level")
        cb2a.set_ticks([0,1,2,3])
        cb2a.set_ticklabels([0,1,2,3])
        plot2a.save("%s/" % ds)

    # projection of temperature (density-weighted) through narrow slab
    fn6 = str(ds) + "/" + str(ds) + "_region_nogrids_Projection_z_temperature_baryon_overdensity.png"
    if os.path.isfile(fn6) is False:
        plot3 = yt.ProjectionPlot(ds,'z',"temperature",weight_field="baryon_overdensity",
                                  center=c,data_source=my_region, field_parameters = {'omega_baryon': 0.046})
        plot3.set_zlim(field='temperature',zmin=1,zmax=1.0e8)
        plot3.set_cmap("temperature","hot")
        plot3.plots['temperature'].axes.get_xaxis().set_visible(False)
        plot3.plots['temperature'].axes.get_yaxis().set_visible(False)
        plot3.annotate_text([0.05,-0.06],'z = %.3f' % ds.current_redshift, text_args={'size':24})
        plot3.annotate_text([0.7,-0.06],'t = %.3f Gyr' % ds.current_time.in_units('Gyr'), text_args={'size':24})
        plot3.save("%s/%s_region_nogrids" % (ds,ds) )
 
    # projection of temperature (density-weighted) through entire volume
    fn7 = str(ds) + "/" + str(ds) + "_Projection_z_temperature_baryon_overdensity.png"
    if os.path.isfile(fn7) is False:
        plot3a = yt.ProjectionPlot(ds,'z',"temperature",weight_field="baryon_overdensity",
                                   center=c, field_parameters = {'omega_baryon': 0.046})
        plot3a.set_zlim(field='temperature',zmin=1,zmax=1.0e8)
        plot3a.set_cmap("temperature","hot")
        plot3a.plots['temperature'].axes.get_xaxis().set_visible(False)
        plot3a.plots['temperature'].axes.get_yaxis().set_visible(False)
        plot3a.annotate_text([0.05,-0.06],'z = %.3f' % ds.current_redshift, text_args={'size':24})
        plot3a.annotate_text([0.7,-0.06],'t = %.3f Gyr' % ds.current_time.in_units('Gyr'), text_args={'size':24})
        plot3a.save("%s/" % ds )
    
    # 2d temperature-density phase diagram, weighted by cell mass
    fn8 = str(ds) + "/" + str(ds) + "_2d-Profile_baryon_overdensity_temperature_cell_mass.png"
    if os.path.isfile(fn8) is False:
        ad = ds.region((ds.domain_right_edge + ds.domain_left_edge)/2., ds.domain_left_edge, ds.domain_right_edge,
                       field_parameters = {'omega_baryon':0.046} )
        phase = yt.create_profile(ad,bin_fields=["baryon_overdensity","temperature"],n_bins=[256,256],
                                  fields=["cell_mass"],weight_field=None,
                                  extrema={'baryon_overdensity':(0.01,1.0e5), 'temperature':(1.0,1.0e9)}, fractional=True  )
        pp = yt.PhasePlot.from_profile(phase)
        pp.set_xlabel('Baryon Overdensity')
        pp.set_zlim(field='all',zmin=1e-8,zmax=1e-2)
        pp.annotate_text(xpos=1e3,ypos=3e8,text='t = %.3f Gyr' % ds.current_time.in_units('Gyr'),fontdict={'size':24})
        pp.annotate_text(xpos=0.05,ypos=3e8,text='z = %.3f' % ds.current_redshift,fontdict={'size':24})
        pp.save("%s/" % ds)

#fin
